@@ -41,7 +41,7 @@ def lastname_en():
         'Beig'
     ]
     some_suffixes = [
-        '', '', '', '', '', '', '', '', '', '', '', '', '',
+        '', '', '', '', '', '', '', '', '', '', '', '', '', '', '',
         'pour',
         'zadeh',
         'far',
@@ -53,8 +53,10 @@ def lastname_en():
         'khah',
         'nia',
         'mehr',
+        'azar',
         'nejad',
-        'bayat'
+        'bayat',
+        'yekta'
     ]
     more_suffixes = [
         'i', 'i', 'i', 'i', 'i', 'i', 'i', 'i', 'i', 'i', 'i',
@@ -159,7 +161,7 @@ def lastname_fa():
         'بیگ '
     ]
     some_suffixes = [
-        '', '', '', '', '', '', '', '', '', '', '', '', '',
+        '', '', '', '', '', '', '', '', '', '', '', '', '', '', '',
         ' پور',
         ' زاده',
         ' فر',
@@ -171,8 +173,10 @@ def lastname_fa():
         ' خواه',
         ' نیا',
         ' مهر',
+        ' آذر',
         ' نژاد',
-        ' بیات'
+        ' بیات',
+        ' یکتا'
     ]
     more_suffixes = [
         'ی', 'ی', 'ی', 'ی', 'ی', 'ی', 'ی', 'ی', 'ی', 'ی', 'ی',
